==> owncloud-10.0.3.tgz: owncloud/apps/federatedfilesharing/l10n/gl.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "ID de nube federada incorrecto",
    "Sharing %s failed, because this item is already shared with %s" : "Fallou a compartición de %s, este elemento xa está compartido con %s",
    "Not allowed to create a federated share with the same user" : "Non está permitido crear unha compartición federada co mesmo usuario",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Fallou a compartición de %s, non foi posíbel atopar %s,é probábel que o servidor non estea accesíbel.",
    "Accept" : "Aceptar",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Comparte comigo a través do meu ID da nube federada do #ownCloud , vexa %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Comparte comigo a través do meu ID da nube federada do #ownCloud",
    "Federated Cloud Sharing" : "Nube federada compartida",
    "Open documentation" : "Abrir a documentación",
    "Allow users on this server to send shares to other servers" : "Permitir aos usuarios deste servidor enviar comparticións a outros servidores",
    "Allow users on this server to receive shares from other servers" : "Permitir aos usuarios deste servidor recibir comparticións de outros servidores",
    "Federated Cloud" : "Nube federada",
    "Your Federated Cloud ID:" : "ID da súa nube federada:",
    "Share it:" : "Compártao:",
    "Share with me via ownCloud" : "Comparte comigo a través do ownCloud",
    "HTML Code:" : "Código HTML:"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/federatedfilesharing/l10n/gl.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "ID de nube federada incorrecto",
    "Sharing %s failed, because this item is already shared with %s" : "Fallou a compartición de %s, este elemento xa está compartido con %s",
    "Not allowed to create a federated share with the same user" : "Non está permitido crear unha compartición federada co mesmo usuario",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Fallou a compartición de %s, non foi posíbel atopar %s,é probábel que o servidor non estea accesíbel.",
    "Accept" : "Aceptar",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Comparte comigo a través do meu ID da nube federada do #ownCloud , vexa %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Comparte comigo a través do meu ID da nube federada do #ownCloud",
    "Federated Cloud Sharing" : "Nube federada compartida",
    "Open documentation" : "Abrir a documentación",
    "Allow users on this server to send shares to other servers" : "Permitir aos usuarios deste servidor enviar comparticións a outros servidores",
    "Allow users on this server to receive shares from other servers" : "Permitir aos usuarios deste servidor recibir comparticións de outros servidores",
    "Federated Cloud" : "Nube federada",
    "Your Federated Cloud ID:" : "ID da súa nube federada:",
    "Share it:" : "Compártao:",
    "Share with me via ownCloud" : "Comparte comigo a través do ownCloud",
    "HTML Code:" : "Código HTML:",
    "Add to your ownCloud" : "Engadir ao seu ownCloud"
},
"nplurals=2; plural=(n != 1);");
